Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6290)

Unified Diff: chrome/browser/permissions/chooser_permission_context.h

Issue 1382783002: Store USB device permissions in website settings. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove UsbPermissionContext and add ChooserPermissionContext helper functions. Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/permissions/chooser_permission_context.h
diff --git a/chrome/browser/permissions/permission_context.h b/chrome/browser/permissions/chooser_permission_context.h
similarity index 54%
copy from chrome/browser/permissions/permission_context.h
copy to chrome/browser/permissions/chooser_permission_context.h
index 7dfd84edbac55f7bc66889b4c728e3cccbae7097..875e0663d185e855b55693377d5335c67481afed 100644
--- a/chrome/browser/permissions/permission_context.h
+++ b/chrome/browser/permissions/chooser_permission_context.h
@@ -2,15 +2,15 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_PERMISSIONS_PERMISSION_CONTEXT_H_
-#define CHROME_BROWSER_PERMISSIONS_PERMISSION_CONTEXT_H_
+#ifndef CHROME_BROWSER_PERMISSIONS_CHOOSER_PERMISSION_CONTEXT_H_
+#define CHROME_BROWSER_PERMISSIONS_CHOOSER_PERMISSION_CONTEXT_H_
#include <list>
#include "base/macros.h"
#include "components/content_settings/core/common/content_settings_types.h"
-class PermissionContextBase;
+class ChooserPermissionContextBase;
class Profile;
class KeyedServiceBaseFactory;
@@ -18,24 +18,24 @@ namespace content {
enum class PermissionType;
}; // namespace content
-class PermissionContext {
+class ChooserPermissionContext {
raymes 2015/10/14 02:07:04 Can we avoid adding this entire class for the time
Reilly Grant (use Gerrit) 2015/10/22 00:57:02 It's used in my next patch and it makes more sense
raymes 2015/10/29 06:14:40 I don't feel entirely convinced that this is neede
Reilly Grant (use Gerrit) 2015/10/29 20:59:59 Done.
public:
// Helper method returning the PermissionContextBase object associated with
// the given ContentSettingsType.
// This can return nullptr if the the permission type has no associated
// context.
- static PermissionContextBase* Get(
+ static ChooserPermissionContextBase* Get(
Profile* profile,
content::PermissionType content_settings_type);
// Return all the factories related to PermissionContext. These are the
// factories used by ::Get() to create a PermissionContextBase.
// This is meant to be used by callers of ::Get() that need to depend on these
// factories.
static const std::list<KeyedServiceBaseFactory*>& GetFactories();
private:
- DISALLOW_IMPLICIT_CONSTRUCTORS(PermissionContext);
+ DISALLOW_IMPLICIT_CONSTRUCTORS(ChooserPermissionContext);
};
-#endif // CHROME_BROWSER_PERMISSIONS_PERMISSION_CONTEXT_H_
+#endif // CHROME_BROWSER_PERMISSIONS_CHOOSER_PERMISSION_CONTEXT_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -18,24 +18,24 @@ namespace content {
Reilly Grant (use Gerrit) 2015/10/29 20:59:59 Done.
public:
- // Helper method returning the PermissionContextBase object associated with
- // the given ContentSettingsType.
+ // Helper method returning the ChooserPermissionContextBase object associated
+ // with the given ContentSettingsType.
// This can return nullptr if the the permission type has no associated
// context.
@@ -18,24 +18,24 @@ namespace content {
Profile* profile,
content::PermissionType content_settings_type);
- // Return all the factories related to PermissionContext. These are the
- // factories used by ::Get() to create a PermissionContextBase.
+ // Return all the factories related to ChooserPermissionContext. These are the
+ // factories used by ::Get() to create a ChooserPermissionContextBase.
// This is meant to be used by callers of ::Get() that need to depend on these
// factories.